==> vue-bulletin-board-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/bulletin-board/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import Tabs from "@dftvue2-opentiny/vue-tabs";
import TabItem from "@dftvue2-opentiny/vue-tab-item";
import { iconChevronRight } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "icon", "showMore", "moreLink", "tabTitle", "activeName", "data"]),
  components: {
    Tabs,
    TabItem,
    IconChevronRight: iconChevronRight()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-bulletin-board"
  }, [_c("p", {
    staticClass: "tiny-bulletin-board__title"
  }, [_vm._v(_vm._s(_vm.title))]), _c("tabs", {
    model: {
      value: _vm.state.actName,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "actName", $$v);
      },
      expression: "state.actName"
    }
  }, _vm._l(_vm.tabTitle, function(item, index) {
    return _c("tab-item", {
      key: index,
      attrs: {
        "name": (index + 1).toString()
      },
      scopedSlots: _vm._u([{
        key: "title",
        fn: function fn() {
          return [_c("span", [_vm._v(_vm._s(item))])];
        },
        proxy: true
      }], null, true)
    }, [_c("div", {
      staticClass: "tiny-bulletin-board__contain"
    }, [_vm._l(_vm.state.dataList, function(subItem, subIndex) {
      return _c("div", {
        key: subIndex,
        staticClass: "tiny-bulletin-board__item"
      }, [subItem.url || subItem.route ? _c("a", {
        staticClass: "tiny-bulletin-board__textTitle",
        attrs: {
          "href": subItem.url || _vm.getRoute(subItem.route),
          "target": subItem.target,
          "rel": "noopener noreferrer"
        }
      }, [subIndex === 0 ? _c("span", {
        staticClass: "tiny-bulletin-board__new"
      }, [_c(_vm.icon, {
        tag: "component",
        staticClass: "tiny-svg-size"
      }), _vm._v(_vm._s(_vm.icon ? "" : "NEW") + " ")], 1) : _vm._e(), _vm._v(" " + _vm._s(subItem.text) + " ")]) : _c("span", {
        staticClass: "tiny-bulletin-board__textTitle"
      }, [subIndex === 0 ? _c("span", {
        staticClass: "tiny-bulletin-board__new"
      }, [_c(_vm.icon, {
        tag: "component",
        staticClass: "tiny-svg-size"
      }), _vm._v(_vm._s(_vm.icon ? "" : "NEW") + " ")], 1) : _vm._e(), _vm._v(" " + _vm._s(subItem.text) + " ")]), _c("p", {
        staticClass: "tiny-bulletin-board__textDate"
      }, [_vm._v(_vm._s(subItem.date))])]);
    }), _vm.showMore ? _c("div", {
      staticClass: "tiny-bulletin-board__more"
    }, [_vm.showMore && _vm.state.moreLink && (_vm.state.moreLink.url || _vm.state.moreLink.route) ? _c("a", {
      staticClass: "tiny-bulletin-board__more-link",
      attrs: {
        "href": _vm.state.moreLink.url || _vm.getRoute(_vm.state.moreLink.route),
        "target": _vm.state.moreLink.target,
        "rel": "noopener noreferrer"
      }
    }, [_c("span", [_vm._v(_vm._s(_vm.state.moreLink.text || "more"))]), _c("icon-chevron-right", {
      staticClass: "tiny-svg-size"
    })], 1) : _vm._e()]) : _vm._e()], 2)]);
  }), 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-bulletin-board-2.22.1.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/bulletin-board/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Tabs from '@opentinyvue/vue-tabs';
import TabItem from '@opentinyvue/vue-tab-item';
import { iconChevronRight } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["title", "icon", "showMore", "moreLink", "tabTitle", "activeName", "data"]),
  components: {
    Tabs,
    TabItem,
    IconChevronRight: iconChevronRight()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-bulletin-board"
  }, [_c("p", {
    staticClass: "tiny-bulletin-board__title"
  }, [_vm._v(_vm._s(_vm.title))]), _c("tabs", {
    model: {
      value: _vm.state.actName,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "actName", $$v);
      },
      expression: "state.actName"
    }
  }, _vm._l(_vm.tabTitle, function(item, index) {
    return _c("tab-item", {
      key: index,
      attrs: {
        "name": (index + 1).toString()
      },
      scopedSlots: _vm._u([{
        key: "title",
        fn: function fn() {
          return [_c("span", [_vm._v(_vm._s(item))])];
        },
        proxy: true
      }], null, true)
    }, [_c("div", {
      staticClass: "tiny-bulletin-board__contain"
    }, [_vm._l(_vm.state.dataList, function(subItem, subIndex) {
      return _c("div", {
        key: subIndex,
        staticClass: "tiny-bulletin-board__item"
      }, [subItem.url || subItem.route ? _c("a", {
        staticClass: "tiny-bulletin-board__textTitle",
        attrs: {
          "href": subItem.url || _vm.getRoute(subItem.route),
          "target": subItem.target,
          "rel": "noopener noreferrer"
        },
        on: {
          "click": function click($event) {
            return _vm.handleBulletinBoardClick(subItem);
          }
        }
      }, [_vm._v(" " + _vm._s(subItem.text) + " "), subIndex === 0 ? _c("span", {
        staticClass: "tiny-bulletin-board__new"
      }, [_c(_vm.icon, {
        tag: "component",
        staticClass: "tiny-svg-size"
      }), _vm._v(_vm._s(_vm.icon ? "" : "NEW") + " ")], 1) : _vm._e()]) : _c("span", {
        staticClass: "tiny-bulletin-board__textTitle",
        on: {
          "click": function click($event) {
            return _vm.handleBulletinBoardClick(subItem);
          }
        }
      }, [_vm._v(" " + _vm._s(subItem.text) + " "), subIndex === 0 ? _c("span", {
        staticClass: "tiny-bulletin-board__new"
      }, [_c(_vm.icon, {
        tag: "component",
        staticClass: "tiny-svg-size"
      }), _vm._v(_vm._s(_vm.icon ? "" : "NEW") + " ")], 1) : _vm._e()]), _c("p", {
        staticClass: "tiny-bulletin-board__textDate"
      }, [_vm._v(_vm._s(subItem.date))])]);
    }), _vm.showMore ? _c("div", {
      staticClass: "tiny-bulletin-board__more"
    }, [_vm.showMore && _vm.state.moreLink && (_vm.state.moreLink.url || _vm.state.moreLink.route) ? _c("a", {
      staticClass: "tiny-bulletin-board__more-link",
      attrs: {
        "href": _vm.state.moreLink.url || _vm.getRoute(_vm.state.moreLink.route),
        "target": _vm.state.moreLink.target,
        "rel": "noopener noreferrer"
      }
    }, [_c("span", [_vm._v(_vm._s(_vm.state.moreLink.text || "more"))]), _c("icon-chevron-right", {
      staticClass: "tiny-svg-size"
    })], 1) : _vm._e()]) : _vm._e()], 2)]);
  }), 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
